pub struct Client<P> { /* private fields */ }Expand description
A DNS Client implemented over futures-rs.
This Client is generic and capable of wrapping UDP, TCP, and other underlying DNS protocol implementations.
Implementations
Sourceimpl<P: RuntimeProvider> Client<P>
impl<P: RuntimeProvider> Client<P>
Sourcepub fn new<S: DnsClientStream>(
stream: S,
stream_handle: BufDnsStreamHandle,
) -> (Self, DnsExchangeBackground<DnsMultiplexer<S>, P::Timer>)
pub fn new<S: DnsClientStream>( stream: S, stream_handle: BufDnsStreamHandle, ) -> (Self, DnsExchangeBackground<DnsMultiplexer<S>, P::Timer>)
Spawns a new Client Stream. This uses a default timeout of 5 seconds for all requests.
Arguments
stream- A stream of bytes that can be used to send/receive DNS messages (see TcpClientStream or UdpClientStream)stream_handle- The handle for thestreamon which bytes can be sent/received.
Sourcepub fn with_timeout<S: DnsClientStream>(
stream: S,
stream_handle: BufDnsStreamHandle,
timeout_duration: Duration,
) -> (Self, DnsExchangeBackground<DnsMultiplexer<S>, P::Timer>)
pub fn with_timeout<S: DnsClientStream>( stream: S, stream_handle: BufDnsStreamHandle, timeout_duration: Duration, ) -> (Self, DnsExchangeBackground<DnsMultiplexer<S>, P::Timer>)
Spawns a new Client Stream.
Arguments
stream- A stream of bytes that can be used to send/receive DNS messages (see TcpClientStream or UdpClientStream)stream_handle- The handle for thestreamon which bytes can be sent/received.timeout_duration- All requests may fail due to lack of response, this is the time to wait for a response before canceling the request.
Sourcepub fn from_sender<S: DnsRequestSender>(
sender: S,
) -> (Self, DnsExchangeBackground<S, P::Timer>)
pub fn from_sender<S: DnsRequestSender>( sender: S, ) -> (Self, DnsExchangeBackground<S, P::Timer>)
Creates a Client from an existing DnsRequestSender
Sourcepub fn enable_edns(&mut self)
pub fn enable_edns(&mut self)
(Re-)enable usage of EDNS for outgoing messages
Sourcepub fn disable_edns(&mut self)
pub fn disable_edns(&mut self)
Disable usage of EDNS for outgoing messages